<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fur">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Scurtis platadis</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Chestis scurtis stabilidis a nivel di codiç a vignaran sorescritis se a vignaran ancje assegnadis a altris azions in Preferencis → Scurtis.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Scurte</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Azion</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Siere barcon o jes de modalitât plen visôr</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Diestre</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Imagjin sucessive</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Spazi</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Ultime imagjin</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Çampe</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Imagjin prime</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Cancele cessant</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Inizi</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Prime imagjin</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="97"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Invie a plen visôr (al podarès tornâ util tai gjestôrs di barcons tiling, vâl a dî a mosaic)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Cature une videade (obsolet; dopre screengrab al so puest)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Cature une videade e salvile te cartele cence mostrâ la interface grafiche (obsolet, dopre screengrab al so puest)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="120"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>rispueste di erôr no cognossût</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>rispueste di erôr no cognossût</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>About</source>
        <translation>Informazions</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>A simple and fast image viewer</source>
        <translation>Un sempliç e svelt visualizadôr di imagjins</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Copyright (C) </source>
        <translation>Dirits di autôr © </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>LXQt Project</source>
        <translation>Progjet LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Development: </source>
        <translation>Disvilup: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Author: </source>
        <translation>Autôr: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Open File</source>
        <translation>Vierç file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <location filename="../mainwindow.cpp" line="575"/>
        <source>Image files (%1)</source>
        <translation>Imagjins (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Open directory</source>
        <translation>Vierç cartele</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Save File</source>
        <translation>Salve file</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <location filename="../mainwindow.cpp" line="730"/>
        <location filename="../mainwindow.cpp" line="736"/>
        <location filename="../mainwindow.cpp" line="742"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>%1/%2 Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Daûr a cjariâ...) - Visualizadôr imagjins</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Erôr tal cjariâ) - Visualizadôr imagjins</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visualizadôr imagjins</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visualizadôr imagjins</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>Thumbnails</source>
        <translation>Miniaturis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1492"/>
        <source>EXIF Data</source>
        <translation>Dâts EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Nete</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Dopre un tast modificadôr par netâ vie une
scurte te modalitât di modifiche.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Bottom</source>
        <translation>In bas</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Top</source>
        <translation>Adalt</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Left</source>
        <translation>A çampe</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="343"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Atenzion: scurte ambigue rilevade! (dople?)&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="360"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Scurte ambigue (dople?) no fate buine.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Impussibil salvâ cun chest formât di imagjin!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Dimensions:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Percors:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="48"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="136"/>
        <source>Start</source>
        <translation>Invie</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="139"/>
        <source>Stop</source>
        <translation>Ferme</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="142"/>
        <source>Close</source>
        <translation>Siere</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="149"/>
        <source>Error</source>
        <translation>Erôr</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visualizadôr di imagjins</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;About</source>
        <translation>&amp;Informazions</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="709"/>
        <source>Annotations Toolbar</source>
        <translation>Sbare dai struments des notis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Vierç &amp;cun...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recent Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Sorting</source>
        <translation>Ordenament</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>&amp;Scurtis platadis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>&amp;Open…</source>
        <translation>Vi&amp;erç…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&amp;Reload File</source>
        <translation>To&amp;rne cjame il file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>&amp;Save</source>
        <translation>&amp;Salve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Save &amp;As</source>
        <translation>S&amp;alve come</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Close</source>
        <translation>&amp;Siere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Ingrandìs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Zoom &amp;Out</source>
        <translation>I&amp;mpiçulìs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copie intes notis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Next File</source>
        <translation>File sucessîf</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>PgDown</source>
        <translation>PagjJù</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="356"/>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Previous File</source>
        <translation>File prime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>PgUp</source>
        <translation>PagjSù</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Original Size</source>
        <translation>Dimensions origjinâls</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>&amp;Fit</source>
        <translation>&amp;Adate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Volte in sens o&amp;rari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Volte in sens &amp;antiorari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>P&amp;references</source>
        <translation>P&amp;referencis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>&amp;Print</source>
        <translation>Stam&amp;pe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>First File</source>
        <translation>Prin file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>Home</source>
        <translation>Inizi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Last File</source>
        <translation>Ultin file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>&amp;New Window</source>
        <translation>G&amp;nûf barcon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Ribalte in &amp;orizontâl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Capture Screenshot</source>
        <translation>Cature videade</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>F&amp;ull Screen</source>
        <translation>Plen &amp;visôr</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>Flip &amp;Vertically</source>
        <translation>Ribalte in &amp;verticâl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Tache intes notis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Presentazion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Del</source>
        <translation>Canc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Show Thumbnails</source>
        <translation>Mostre miniaturis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>File Properties</source>
        <translation>Proprietâts dal file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Open &amp;Directory</source>
        <translation>Vierç &amp;cartele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Upload</source>
        <translation>Cjame in rêt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Upload the image</source>
        <translation>Cjame in rêt la imagjin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="598"/>
        <source>Show EXIF Data</source>
        <translation>Mostre dâts EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>No Tool</source>
        <translation>Nissun strument</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Deselect all drawing tools</source>
        <translation>Deselezione ducj i struments di dissen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Draw Arrow</source>
        <translation>Dissegne frece</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Draw an arrow</source>
        <translation>Dissegne une frece</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Draw Rectangle</source>
        <translation>Dissegne retangul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <source>Draw a hollow rectangle</source>
        <translation>Dissegne un retangul vueit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <source>Draw Circle</source>
        <translation>Dissegne cercli</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Draw a hollow circle</source>
        <translation>Dissegne un cercli vueit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Draw Number</source>
        <translation>Dissegne numar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="673"/>
        <source>Draw incrementing numbers</source>
        <translation>Dissegne numars in cressi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Menubar</source>
        <translation>Sbare dai menûs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>&amp;Main Toolbar</source>
        <translation>Sbare dai stru&amp;ments principâl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="698"/>
        <source>Main Toolbar</source>
        <translation>Sbare dai struments principâl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="706"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>Sb&amp;are dai struments des notis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Show Outline</source>
        <translation>Mostre contor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Copy Pa&amp;th</source>
        <translation>Copie &amp;percors</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Copy path</source>
        <translation>Copie percors</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <location filename="../mainwindow.ui" line="745"/>
        <source>Rename</source>
        <translation>Cambie non</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="748"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Resize</source>
        <translation>Ridimensione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>&amp;By File Name</source>
        <translation>Par &amp;non di file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="768"/>
        <source>By File Name</source>
        <translation>Par non di file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>By &amp;Modification Time</source>
        <translation>Par &amp;date di modifiche</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>By Modification Time</source>
        <translation>Par date di modifiche</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="787"/>
        <source>By C&amp;reation Time</source>
        <translation>Par date di &amp;creazion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>By Creation Time</source>
        <translation>Par date di creazion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>By File &amp;Size</source>
        <translation>Par di&amp;mension dal file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>By File Size</source>
        <translation>Par dimension dal file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="809"/>
        <source>By File &amp;Type</source>
        <translation>Par &amp;gjenar di file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="812"/>
        <source>By File Type</source>
        <translation>Par gjenar di file</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="817"/>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="820"/>
        <source>Ctrl+Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Ctrl+Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <source>First Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Last Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Solid Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Help</source>
        <translation>&amp;Jutori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Go</source>
        <translation>Va</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>&amp;View</source>
        <translation>&amp;Visualize</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifiche</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>Toolbar</source>
        <translation>Sbare dai struments</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferencis</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Teme des iconis:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Dimension massime des miniaturis:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Colôr di fonts normâl:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Colôr di fonts a plen visôr:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Numar massim di files resints:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Dade tra lis diapositivis (seconts):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Show image outline by default</source>
        <translation>Come predefinît, mostre il contor de imagjin</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Come predefinît, mostre la sbare dai struments des notis</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Fit images when navigating</source>
        <translation>Adate lis imagjins te navigazion</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensions de miniature:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Dopre la scovacere di sisteme (cence conferme)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Barcon</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Come predefinît, mostre sbare des miniaturis</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Come predefinît, mostre il panel cui dâts Exif</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Come predefinît, mostre la sbare dai menûs</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Come predefinît, mostre la sbare dai struments principâl</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Imagjin</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>Al pues funzionâ nome cun imagjins che a àn spazis di colôr valits.
Torne cjame la imagjin corinte par viodi l&apos;efiet.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>Spazi colôr:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Nissun</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (supuartât de plui part dai visôrs)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>sRGB lineâr(spetri lineâr)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (schermis a ampli spetri)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Solid background by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="263"/>
        <source>Smooth images on zooming</source>
        <translation>Slisse lis imagjins se ingrandidis</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="271"/>
        <source>Shortcuts</source>
        <translation>Scurtis</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="290"/>
        <source>Action</source>
        <translation>Azion</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="295"/>
        <source>Shortcut</source>
        <translation>Scurte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="303"/>
        <source>Default</source>
        <translation>Met predefinît</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Gjenerâls</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Error</source>
        <translation>Erôr</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Ridimensione imagjin</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Largjece</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Altece</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Dimensions atuâls:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Gnovis dimensions:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Manten lis proporzions</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Videade</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Cature une videade</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Regjon</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Schermi intîr</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Nome barcon corint</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Cature une aree dal schermi</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inclût cursôr dal mouse</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Ritart:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inclût titul e curnîs dal barcon</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Cjame in rêt</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copie</translation>
    </message>
</context>
</TS>
